#!/bin/bash

# Source common reset functions
source /etc/stellarmate/reset-factory-common.sh

# Perform common reset operations with stellarmate hostname
perform_common_reset "stellarmate"

cp /etc/stellarmate/kstars/config/* /home/stellarmate/.var/app/org.kde.kstars/config/
cp /etc/stellarmate/kstars/catalogs/* /home/stellarmate/.var/app/org.kde.kstars/data/kstars/

# SM-160 specific operations
sed -i 's|^HIPSOfflinePath=.*|HIPSOfflinePath=/home/stellarmate/.var/app/org.kde.kstars/data/kstars/HIPS|' /home/stellarmate/.var/app/org.kde.kstars/config/kstarsrc

# Reset Plasma settings
cp -rf /etc/stellarmate/plasma/* /home/stellarmate/.config

echo "Reset complete. StellarMate must be restarted now."
